OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalendár",
    "Individual" : "Individuálny",
    "Group" : "Skupina",
    "Resource" : "Zdroj",
    "Room" : "Miestnosť",
    "Unknown" : "Neznámy",
    "Required" : "Vyžadovaný",
    "Optional" : "Voliteľný",
    "Does not attend" : "Nezúčastní sa",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Ste v neznámej časovej zóne ({tz}), používa sa UTC",
    "Please create a calendar first." : "Prosím, najskôr vytvorte kalendár",
    "New event" : "Nová udalosť",
    "group" : "skupina",
    "Attendees" : "Účastníci",
    "Reminders" : "Pripomienky",
    "Repeating" : "Opakovanie",
    "When shared show full event" : "Zobraziť úplnú udalosť, ak je sprístupnená",
    "When shared show only busy" : "Zobraziť zaneprázdnený, ak je udalosť sprístupnená",
    "When shared hide this event" : "Skryť udalosť, ak je sprístupnená",
    "Confirmed" : "Potvrdené",
    "Tentative" : "Neistý",
    "Cancelled" : "Zrušené",
    "Please add a title!" : "Prosím pridajte názov!",
    "Please select a calendar!" : "Prosím vyberte kalendár",
    "Global" : "Globálny",
    "None" : "Žiadny",
    "Every day" : "Každý deň",
    "Every week" : "Každý týždeň",
    "Every month" : "Každý mesiac",
    "Every year" : "Každý rok",
    "never" : "nikdy",
    "after" : "po",
    "At time of event" : "Pridajte čas udalosti",
    "5 minutes before" : "5 minút pred",
    "10 minutes before" : "10 minút pred",
    "15 minutes before" : "15 minút pred",
    "30 minutes before" : "30 minút pred",
    "1 hour before" : "1 hodinu pred",
    "2 hours before" : "2 hodiny pred",
    "Custom" : "Vlastný",
    "Audio" : "Zvuk",
    "E Mail" : "E-mail",
    "sec" : "sek",
    "min" : "min",
    "hours" : "hodín",
    "days" : "dni",
    "week" : "týždeň",
    "before" : "pred",
    "start" : "začiatok",
    "end" : "koniec",
    "Week {number} of {year}" : "Týždeň {number} roku {year}",
    "Successfully imported" : "Úspešne importovaný",
    "Partially imported, 1 failure" : "Čiastočne importovaný, 1 chyba",
    "Partially imported, {n} failures" : "Čiastočne importovaný, {n} chýb",
    "Audio alarm" : "Zvukový alarm",
    "E-Mail" : "email",
    "{type} {time} before the event starts" : "{type} {time} pred začiatkom udalosti",
    "{type} {time} before the event ends" : "{type} {time} pred koncom udalosti",
    "{type} {time} after the event starts" : "{type} {time} po začiatku udalosti",
    "{type} {time} after the event ends" : "{type} {time} po ukončení udalosti",
    "{type} at the event's start" : "{type} pri začiatku udalosti",
    "{type} at the event's end" : "{type} pri skončení udalosti",
    "{type} at {time}" : "{type} o {time}",
    "{calendar} shared by {owner}" : "{calendar} sprístupňuje {owner}",
    "Title of the Event" : "Názov udalosti",
    "starts" : "začína",
    "ends" : "končí",
    "All day Event" : "Celodenná udalosť",
    "Delete" : "Zmazať",
    "Cancel" : "Zrušiť",
    "More ..." : "Viac ...",
    "Create" : "Vytvoriť",
    "Update" : "Aktualizovať",
    "Close" : "Zavrieť",
    "Location" : "Umiestnenie",
    "Description" : "Popis",
    "Event status" : "Stav udalosti",
    "Visibility when sharing" : "Viditelnosť pri sprístupnení",
    "Export" : "Export",
    "Day" : "Deň",
    "Week" : "Týždeň",
    "Month" : "Mesiac",
    "Today" : "Dnes",
    "Share Calendar" : "Sprístupniť kalendár",
    "Shared" : "Sprístupnené",
    "More" : "Viac",
    "Edit" : "Upraviť",
    "Link" : "Odkaz",
    "Download" : "Sťahovanie",
    "Share with users or groups" : "Sprístupniť používateľom alebo skupinám",
    "can edit" : "môže upraviť",
    "New Calendar" : "Nový kalendár",
    "Name" : "Názov",
    "New Subscription" : "Nový odber",
    "Edit event" : "Upraviť udalosť",
    "Delete Event" : "Zmazať udalosť",
    "Save Event" : "Uložiť udalosť",
    "Time" : "Čas",
    "Type" : "Typ",
    "Relative" : "Relatívny",
    "Absolute" : "Absolútny",
    "Repeat" : "Opakovať",
    "Add" : "Pridať",
    "E-Mail address of attendee" : "E-mail adresa účastníka",
    "from" : "od",
    "to" : "do",
    "Support for advanced rules will be added with subsequent updates." : "Podpora pre rozšírené pravidlá bude pridaná v ďalších aktualizáciách.",
    "Repeat every ..." : "Opakovať každý ...",
    "end repeat ..." : "ukončiť opakovanie ...",
    "times" : "krát",
    "Import Calendars" : "Importovať kalendáre",
    "Import canceled" : "Import zrušený",
    "Analyzing calendar" : "Analyzujem kalendár",
    "New calendar" : "Nový kalendár",
    "Import scheduled" : "Import naplánovaný",
    "Settings" : "Nastavenia",
    "Import calendar" : "Importovať kalendár",
    "No Calendars selected for import" : "Nebol označený kalendár na import",
    "Primary CalDAV address" : "Primárna CalDAV adresa",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV adresa"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
